Structs

A struct holding data to plot a Histogram of the most frequent terms in an arbitrary input.

A struct holding data to plot a Histogram of numerical data.

A struct holding data to plot a MatchBar: a histogram of the number of occurrences of a set of strings in some input dara.

A struct that represents a single match bar of a match bar histogram (a bucket for a term/label).

A struct holding data to plot a split time histogram, where the display shows the frequency of selected terms over time.

A struct holding data to plot a TimeHistogram of timestamp data.

A struct holding data to plot a XY graph.